@@ -5,16 +5,10 @@ A PyTorch implementation of ChunkFormer for automatic speech recognition (ASR)
 that efficiently handles long-form audio transcription on low-memory GPUs.
 """
 
-__version__ = "0.1.0"
-__author__ = "khanhld"
+__version__ = "1.2.2"
+__author__ = "khanld"
 __email__ = "khanhld218@gmail.com"
 
-from .chunkformer_model import ChunkFormerModel, ChunkFormerConfig
-from .decode import ChunkFormerDecoder
+from chunkformer.chunkformer_model import ChunkFormerModel
 
-__all__ = [
-    "ChunkFormerModel",
-    "ChunkFormerConfig", 
-    "ChunkFormerDecoder",
-    "__version__"
-]
\ No newline at end of file
+__all__ = ["ChunkFormerModel", "__version__"]
